'''Game main module.

Contains the entry point used by the run_game.py script.

Feel free to put all your game code here, or in other modules in this "lib"
directory.
'''
import os
import data

import pygame
pygame.init()
pygame.sound_vol=1
pygame.music_vol=1

from effects import *
from util import *
from states import *
from graphics import *

def main():
    #Set up screen and clear it black
    os.environ['SDL_VIDEO_CENTERED'] = '1'
    screen = pygame.display.set_mode([640,480],pygame.DOUBLEBUF)
    screen.fill([0,0,0])
    #Dont show system mouse
    pygame.mouse.set_visible(False)

    #Load backdrops
    back1 = data.loadimage('backdrops/fruitcent.jpg')
    #See effects.py - scale the image so that its width
    #   matches the screen width
    back1 = scale(back1,width=640)
    back2 = data.loadimage('backdrops/titlescreen.png')

    #Calculate height to vertically center the backdrop
    y = (480-back1.get_height())/2.0

    #See util.py and effects.py for these functions
    #Handle fading and timing
    skipper = Handler()  #Make a handler for skipping scenes
    fanfare = pygame.mixer.Sound(data.filepath('sounds/20fox-fanfare.ogg'))
    try:
        pause(2,handler=skipper)
        fanfare.play()
        fade(back1,4,[0,y],handler=skipper)
        pause(6,handler=skipper)
        fade(back1,4,[0,y],mode=-1,handler=skipper)
        pause(1,handler=skipper)
    except SkipAnim:
        pass
    fanfare.stop()

    #Start music track
    pygame.mixer.music.set_volume(pygame.music_vol)
    pygame.mixer.music.load(data.filepath('music/song1.ogg'))
    pygame.mixer.music.play(-1)
    #Calculate new height to center next backdrop
    y = (480-back2.get_height())/2.0
    try:
        fade(back2,4,[0,y],handler=skipper)
    except SkipAnim:
        fade(back2,0.01,[0,y])
        pass
    
    #Load and show mouse
    main_menu = GameState()
    main_menu.backdrop = back2
    start_game = Button()
    start_game.updatetext('Startoozo')
    start_game.loadimage('gui/button_1.png')
    start_game.pos = [50,300]
    start_game.click_event = main_menu.start
    quit_game = Button()
    quit_game.updatetext('Quittar')
    quit_game.loadimage('gui/button_1.png')
    quit_game.pos = [50,360]
    quit_game.click_event = main_menu.quit

    main_menu.world.append(start_game)
    main_menu.world.append(quit_game)
    main_menu.sort_world()

    state = main_menu

    while state:
        state = state.loop()
        if state:
            state = state()
